package org.dromara.zhishu.mapper;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Mapper;
import org.dromara.zhishu.domain.NewUserInfo;
import org.dromara.zhishu.domain.UserTAudit;
import org.dromara.zhishu.domain.bo.UserTAuditBo;
import org.dromara.zhishu.domain.vo.UserTAuditVo;
import org.dromara.common.mybatis.core.mapper.BaseMapperPlus;
import org.springframework.data.repository.query.Param;

import java.util.Collection;

/**
 * 列表Mapper接口
 *
 * @author Lion Li
 * @date 2025-04-02
 */
@Mapper
public interface UserTAuditMapper extends BaseMapperPlus<UserTAudit, UserTAuditVo> {
    NewUserInfo selectUserList(Long id);
    String selectUserName(Long userId);

    Long selectId(Long userId);

    Page<UserTAuditVo> customPageList(@Param("page") Page<UserTAuditVo> page, @Param("bo") UserTAuditBo bo);

    NewUserInfo selectU(Long id);

    UserTAuditVo selectM(Long auditId);

    String selectStatus(Long id);

    Boolean updateUserId(UserTAudit update);

    Long selectAudit(Collection<Long> ids);

    Integer deleteAudit(Long auditId);

    Long deleteByAudit(Collection<Long> ids);

    UserTAuditVo getAuditLog(Long message);
}
